@@ -30,27 +30,14 @@
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
-#ifdef G_OS_WIN32
-# define WIFEXITED(x) ((x) != 3)
-# define WEXITSTATUS(x) (x)
-#else
-# include <sys/wait.h>
-#endif
+#include <sys/wait.h>
 
 #include "comics-document.h"
 #include "ev-document-misc.h"
 #include "ev-document-thumbnails.h"
 #include "ev-file-helpers.h"
 
-#ifdef G_OS_WIN32
-/* On windows g_spawn_command_line_sync reads stdout in O_BINARY mode, not in O_TEXT mode.
- * As a consequence, newlines are in a platform dependent representation (\r\n). This
- * might be considered a bug in glib.
- */
-#define EV_EOL "\r\n"
-#else
 #define EV_EOL "\n"
-#endif
 
 typedef enum
 {
@@ -678,13 +665,15 @@ comics_document_get_page_size (EvDocument *document,
 				gdk_pixbuf_loader_close (loader, NULL);
 			}
 		}
-		pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
-		if (pixbuf) {
+
+		if (gdk_pixbuf_loader_get_pixbuf (loader)) {
+			pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
 			if (width)
 				*width = gdk_pixbuf_get_width (pixbuf);
 			if (height)
 				*height = gdk_pixbuf_get_height (pixbuf);
 		}
+
 		g_spawn_close_pid (child_pid);
 		g_object_unref (loader);
 	} else {
@@ -692,14 +681,11 @@ comics_document_get_page_size (EvDocument *document,
                                              (char *) comics_document->page_names->pdata[page->index],
 					     NULL);
 		pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-		if (pixbuf) {
-			if (width)
-				*width = gdk_pixbuf_get_width (pixbuf);
-			if (height)
-				*height = gdk_pixbuf_get_height (pixbuf);
-			g_object_unref (pixbuf);
-		}
 		g_free (filename);
+		if (width)
+			*width = gdk_pixbuf_get_width (pixbuf);
+		if (height)
+			*height = gdk_pixbuf_get_height (pixbuf);
 	}
 }
 
@@ -716,7 +702,7 @@ comics_document_render_pixbuf (EvDocument      *document,
 			       EvRenderContext *rc)
 {
 	GdkPixbufLoader *loader;
-	GdkPixbuf *rotated_pixbuf, *tmp_pixbuf;
+	GdkPixbuf *rotated_pixbuf;
 	char **argv;
 	guchar buf[4096];
 	gboolean success;
@@ -755,10 +741,10 @@ comics_document_render_pixbuf (EvDocument      *document,
 				outpipe = -1;
 			}
 		}
-		tmp_pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
-		rotated_pixbuf =
-			gdk_pixbuf_rotate_simple (tmp_pixbuf,
-						  360 - rc->rotation);
+
+		rotated_pixbuf = gdk_pixbuf_rotate_simple (
+					gdk_pixbuf_loader_get_pixbuf (loader),
+					360 - rc->rotation);
 		g_spawn_close_pid (child_pid);
 		g_object_unref (loader);
 	} else {
@@ -769,15 +755,13 @@ comics_document_render_pixbuf (EvDocument      *document,
 	   
 		gdk_pixbuf_get_file_info (filename, &width, &height);
 		
-		tmp_pixbuf =
-			gdk_pixbuf_new_from_file_at_size (
-				    filename, width * (rc->scale) + 0.5,
-				    height * (rc->scale) + 0.5, NULL);
-		rotated_pixbuf =
-			gdk_pixbuf_rotate_simple (tmp_pixbuf,
-						  360 - rc->rotation);
+		rotated_pixbuf = 
+		  gdk_pixbuf_rotate_simple (gdk_pixbuf_new_from_file_at_size (
+					    filename, width * (rc->scale) + 0.5,
+					    height * (rc->scale) + 0.5, NULL),
+					    360 - rc->rotation);
 		g_free (filename);
-		g_object_unref (tmp_pixbuf);
+	
 	}
 	return rotated_pixbuf;
 }
@@ -972,7 +956,7 @@ extract_argv (EvDocument *document, gint page)
                 return NULL;
 
 	if (comics_document->regex_arg) {
-		quoted_archive = g_shell_quote (comics_document->archive);
+		quoted_archive = comics_regex_quote (comics_document->archive);
 		quoted_filename =
 			comics_regex_quote (comics_document->page_names->pdata[page]);
 	} else {
