@@ -62,9 +62,6 @@ struct _EvApplication {
 	TotemScrsaver *scr_saver;
 
 	EggSMClient *smclient;
-
-	gchar *filechooser_open_uri;
-	gchar *filechooser_save_uri;
 };
 
 struct _EvApplicationClass {
@@ -938,10 +935,6 @@ ev_application_shutdown (EvApplication *application)
         application->dot_dir = NULL;
         g_free (application->data_dir);
         application->data_dir = NULL;
-	g_free (application->filechooser_open_uri);
-        application->filechooser_open_uri = NULL;
-	g_free (application->filechooser_save_uri);
-	application->filechooser_save_uri = NULL;
 
 	g_object_unref (application);
         instance = NULL;
@@ -1076,35 +1069,6 @@ ev_application_get_media_keys (EvApplication *application)
 #endif /* ENABLE_DBUS */
 }
 
-void
-ev_application_set_filechooser_uri (EvApplication       *application,
-				    GtkFileChooserAction action,
-				    const gchar         *uri)
-{
-	if (action == GTK_FILE_CHOOSER_ACTION_OPEN) {
-		g_free (application->filechooser_open_uri);
-		application->filechooser_open_uri = g_strdup (uri);
-	} else if (action == GTK_FILE_CHOOSER_ACTION_SAVE) {
-		g_free (application->filechooser_save_uri);
-		application->filechooser_save_uri = g_strdup (uri);
-	}
-}
-
-const gchar *
-ev_application_get_filechooser_uri (EvApplication       *application,
-				    GtkFileChooserAction action)
-{
-	if (action == GTK_FILE_CHOOSER_ACTION_OPEN) {
-		if (application->filechooser_open_uri)
-			return application->filechooser_open_uri;
-	} else if (action == GTK_FILE_CHOOSER_ACTION_SAVE) {
-		if (application->filechooser_save_uri)
-			return application->filechooser_save_uri;
-	}
-
-	return NULL;
-}
-
 void
 ev_application_screensaver_enable (EvApplication *application)
 {
